==> tas-sender-client-0.0.16-SNAPSHOT-sources.jar: com/humuson/tas/sender/client/WebPushSendService.java <==
package com.humuson.tas.sender.client;

import java.util.concurrent.TimeUnit;

import org.apache.kafka.clients.producer.Callback;
import org.apache.kafka.clients.producer.Producer;
import org.apache.kafka.clients.producer.ProducerRecord;
import org.apache.kafka.clients.producer.RecordMetadata;

import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.humuson.tas.sender.model.push.WebPushPayload;

import lombok.extern.slf4j.Slf4j;

@Slf4j
public class WebPushSendService implements KafkaService<WebPushPayload>{
	private static final String DEV_WEBPUSH_TOPIC = "dev-web-push-request";
	private static final String PROD_WEBPUSH_TOPIC = "prod-web-push-request";
	private static final long DEFAULT_TIMEOUT_MILLISECONDS = 5000;
	private Producer<String, String> pushProducer;
	private ObjectMapper mapper;
	
	@Override
	public void init() {
		pushProducer = KafkaConnectionFactory.getProducer();
		mapper = new ObjectMapper();
	}
	
	@Override
	public void send(final WebPushPayload payload) throws JsonProcessingException {
		this.send(payload, true);
	}
	
	@Override
	public void send(final WebPushPayload payload, boolean isProduct) throws JsonProcessingException {
		final String data = this.mapper.writeValueAsString(payload);
		final String topic = isProduct? PROD_WEBPUSH_TOPIC : DEV_WEBPUSH_TOPIC;
		this.send(topic, data);
	}
	
	@Override
	public void send(final String topic, final WebPushPayload payload) throws JsonProcessingException {
		final String data = this.mapper.writeValueAsString(payload);
		this.send(topic, data);
	}

	@Override
	public void send(final String topic, final String data) {
		try {
			pushProducer.send(new ProducerRecord<String, String>(topic, data), new Callback() {

				@Override
				public void onCompletion(RecordMetadata metadata, Exception exception) {
					if (exception != null) {
						log.error("send error :{}", data);
			        }
					if (log.isDebugEnabled()) {
						log.debug("send complete:[topic:{}, data:{}]", topic, data);
					}
				}
			}).wait(5000);
		} catch (InterruptedException e) {
			log.error("send produce error", e);
		};
	}

	@Override
	public void close() {
		if (pushProducer != null) {
			try {
				pushProducer.close();
			} catch (Exception e) {
				log.error("kafka producer close error", e);
			}
		}
	}
	
	@Override
	public boolean sendSync(WebPushPayload payload) throws Exception {
		return this.sendSync(payload, true);
	}

	@Override
	public boolean sendSync(WebPushPayload payload, boolean isProduct) throws Exception{
		return this.sendSync(payload, isProduct, DEFAULT_TIMEOUT_MILLISECONDS);
	}

	@Override
	public boolean sendSync(WebPushPayload payload, boolean isProduct, long timeout) throws Exception{
		final String topic = isProduct? PROD_WEBPUSH_TOPIC : DEV_WEBPUSH_TOPIC;
		return this.sendSync(topic, payload, timeout);
	}
	
	@Override
	public boolean sendSync(String topic, WebPushPayload payload)
			throws Exception {
		return this.sendSync(topic, payload, DEFAULT_TIMEOUT_MILLISECONDS);
	}

	@Override
	public boolean sendSync(String topic, WebPushPayload payload, long timeout)
			throws Exception {
		try {
			final String data = this.mapper.writeValueAsString(payload);
			RecordMetadata recodeMetadata = pushProducer.send(new ProducerRecord<String, String>(topic, data)).get(DEFAULT_TIMEOUT_MILLISECONDS, TimeUnit.MILLISECONDS);
			if (log.isDebugEnabled()) {
				log.debug("topic:{}, partition:{}, checksum:{}", recodeMetadata.topic(), recodeMetadata.partition(), recodeMetadata.checksum());
			}
			return true;
		} catch (Exception e) {
			log.error("send kafka error", e);
			throw e;
		}
	}
	
	public static void main(String[] args) {
		WebPushSendService s = new WebPushSendService();
		s.init();
		String json = "{\"APP_GRP_KEY\":\"53a6eb88-6e15-4aec-b3e6-e6390769aa0e\",\"UUID\":\"20cdbf41-368b-4ae1-9344-25b461787187\",\"TITLE\":\"TAS 웹푸시 이벤트\",\"MESSAGE\":\"차효석 고객님! 모바일 앱 없이 푸시를 발송할 수 있는 TAS 웹푸시를 체험하셨습니다. 이벤트 상품 확인하세요!\",\"PUSH_IMG_URL\":\"https://img-mkt.tason.com/postman2011/event/seminar_180313/gift_new.png\",\"TTL\":0,\"REQUEST_UID\":\"140524|195|166|953|8eac8f3c-527f-4443-b249-dc78d02aa041|8eac8f3c-527f-4443-b249-dc78d02aa041\",\"REPORT_QUEUE\":\"dev-web-push-report\",\"LANDING_URL\":\"https://tason.com/event/webpush/thanks\"}";
		String json2 = "{\"APP_GRP_KEY\": \"8772750e-176a-4d81-af2a-364195aea294\","
//				+ " \"CUST_ID\":\"8a399a63-4e39-42b1-b29f-4e198ea99374\"," // -- chrome mobile
				+ " \"CUST_ID\":\"1061c5c3-00c5-41fd-b10d-fb0d0209d1fd\"," //-- PC
//				+ " \"CUST_ID\":\"89356465-2385-4238-b391-a57406b93417\"," // samsung internet browser 
				+ " \"ICON_URL\":\"https://img-amc.tason.com/resources/renewal/images/tas-favicon.ico\","
				+ " \"TITLE\":\"push test\","
				+ " \"PUSH_IMG_URL\":\"https://media.shilladfs.com/medias/sys_master/images/h4d/hff/11758417739806.jpg\","
				+ " \"MESSAGE\":\"push msg test\", "
				+ " \"LANDING_URL\": \"https://www.tason.com\","
				+ " \"REQUEST_UID\":\"1234567890\"}";
		
//		0117ad10-f7ec-4fdb-8bd0-12dc2c97af36
//		String json = "{\"APP_GRP_KEY\": \"8772750e-176a-4d81-af2a-364195aea294\", \"CUST_ID\":\"0117ad10-f7ec-4fdb-8bd0-12dc2c97af36\", \"ICON_URL\":\"https://img-amc.tason.com/resources/renewal/images/tas-favicon.ico\", \"TITLE\":\"push test\", \"MESSAGE\":\"push msg test\", \"LANDING_URL\": \"https://www.tason.com\", \"REQUEST_UID\":\"1234567890\"}"; 
		ObjectMapper mapper = new ObjectMapper();
		
		WebPushPayload payload;
		try {
			payload = mapper.readValue(json, WebPushPayload.class);
			payload.setPushKey("l");
			payload.setPushValue("https://jsonlint.com/");
			payload.setReportQueue("dev-web-push-report");
			System.out.println("payload :"+payload.getUuid());
			s.sendSync(payload);
			
		} catch (Exception e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		} finally {
			if (s != null) s.close();
		}
		
	}
}

==> tas-sender-client-0.1.1-SNAPSHOT-sources.jar: com/humuson/tas/sender/client/WebPushSendService.java <==
package com.humuson.tas.sender.client;

import java.util.concurrent.TimeUnit;

import org.apache.kafka.clients.producer.Callback;
import org.apache.kafka.clients.producer.Producer;
import org.apache.kafka.clients.producer.ProducerRecord;
import org.apache.kafka.clients.producer.RecordMetadata;

import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.humuson.tas.sender.model.push.WebPushPayload;

import lombok.extern.slf4j.Slf4j;

@Slf4j
public class WebPushSendService implements KafkaService<WebPushPayload>{
	private static final String DEV_WEBPUSH_TOPIC = "dev-web-push-request";
	private static final String PROD_WEBPUSH_TOPIC = "prod-web-push-request";
	private static final long DEFAULT_TIMEOUT_MILLISECONDS = 5000;
	private Producer<String, String> pushProducer;
	private ObjectMapper mapper;
	
	@Override
	public void init() {
		pushProducer = KafkaConnectionFactory.getProducer();
		mapper = new ObjectMapper();
	}
	
	@Override
	public void send(final WebPushPayload payload) throws JsonProcessingException {
		this.send(payload, true);
	}
	
	@Override
	public void send(final WebPushPayload payload, boolean isProduct) throws JsonProcessingException {
		final String data = this.mapper.writeValueAsString(payload);
		final String topic = isProduct? PROD_WEBPUSH_TOPIC : DEV_WEBPUSH_TOPIC;
		this.send(topic, data);
	}
	
	@Override
	public void send(final String topic, final WebPushPayload payload) throws JsonProcessingException {
		final String data = this.mapper.writeValueAsString(payload);
		this.send(topic, data);
	}

	@Override
	public void send(final String topic, final String data) {
		pushProducer.send(new ProducerRecord<String, String>(topic, data), new Callback() {

			@Override
			public void onCompletion(RecordMetadata metadata, Exception exception) {
				if (exception != null) {
					log.error("send error :{}", data);
		        }
				if (log.isDebugEnabled()) {
					log.debug("send complete:[topic:{}, data:{}]", topic, data);
				}
			}
		});
	}

	@Override
	public void close() {
		if (pushProducer != null) {
			try {
				pushProducer.close();
			} catch (Exception e) {
				log.error("kafka producer close error", e);
			}
		}
	}
	
	@Override
	public boolean sendSync(WebPushPayload payload) throws Exception {
		return this.sendSync(payload, true);
	}

	@Override
	public boolean sendSync(WebPushPayload payload, boolean isProduct) throws Exception{
		return this.sendSync(payload, isProduct, DEFAULT_TIMEOUT_MILLISECONDS);
	}

	@Override
	public boolean sendSync(WebPushPayload payload, boolean isProduct, long timeout) throws Exception{
		final String topic = isProduct? PROD_WEBPUSH_TOPIC : DEV_WEBPUSH_TOPIC;
		return this.sendSync(topic, payload, timeout);
	}
	
	@Override
	public boolean sendSync(String topic, WebPushPayload payload)
			throws Exception {
		return this.sendSync(topic, payload, DEFAULT_TIMEOUT_MILLISECONDS);
	}

	@Override
	public boolean sendSync(String topic, WebPushPayload payload, long timeout)
			throws Exception {
		try {
			final String data = this.mapper.writeValueAsString(payload);
			RecordMetadata recodeMetadata = pushProducer.send(new ProducerRecord<String, String>(topic, data)).get(DEFAULT_TIMEOUT_MILLISECONDS, TimeUnit.MILLISECONDS);
			if (log.isDebugEnabled()) {
				log.debug("topic:{}, partition:{}, checksum:{}", recodeMetadata.topic(), recodeMetadata.partition(), recodeMetadata.checksum());
			}
			return true;
		} catch (Exception e) {
			log.error("send kafka error", e);
			throw e;
		}
	}
	
	public static void main(String[] args) {
		WebPushSendService s = new WebPushSendService();
		s.init();
		String json = "{\"APP_GRP_KEY\":\"8772750e-176a-4d81-af2a-364195aea294\",\"UUID\":\"8a399a63-4e39-42b1-b29f-4e198ea99374\",\"TITLE\":\"TAS 웹푸시 이벤트\",\"MESSAGE\":\"차효석 고객님! 모바일 앱 없이 푸시를 발송할 수 있는 TAS 웹푸시를 체험하셨습니다. 이벤트 상품 확인하세요!\",\"PUSH_IMG_URL\":\"https://img-mkt.tason.com/postman2011/event/seminar_180313/gift_new.png\",\"TTL\":0,\"REQUEST_UID\":\"140524|195|166|953|8eac8f3c-527f-4443-b249-dc78d02aa041|8eac8f3c-527f-4443-b249-dc78d02aa041\",\"REPORT_QUEUE\":\"dev-web-push-report\",\"LANDING_URL\":\"https://tason.com/event/webpush/thanks\"}";
		String json2 = "{\"APP_GRP_KEY\": \"8772750e-176a-4d81-af2a-364195aea294\","
//				+ " \"CUST_ID\":\"8a399a63-4e39-42b1-b29f-4e198ea99374\"," // -- chrome mobile
				+ " \"CUST_ID\":\"1061c5c3-00c5-41fd-b10d-fb0d0209d1fd\"," //-- PC
//				+ " \"CUST_ID\":\"89356465-2385-4238-b391-a57406b93417\"," // samsung internet browser 
				+ " \"ICON_URL\":\"https://img-amc.tason.com/resources/renewal/images/tas-favicon.ico\","
				+ " \"TITLE\":\"push test\","
				+ " \"PUSH_IMG_URL\":\"https://media.shilladfs.com/medias/sys_master/images/h4d/hff/11758417739806.jpg\","
				+ " \"MESSAGE\":\"push msg test\", "
				+ " \"LANDING_URL\": \"https://www.tason.com\","
				+ " \"REQUEST_UID\":\"1234567890\"}";
		
//		0117ad10-f7ec-4fdb-8bd0-12dc2c97af36
//		String json = "{\"APP_GRP_KEY\": \"8772750e-176a-4d81-af2a-364195aea294\", \"CUST_ID\":\"0117ad10-f7ec-4fdb-8bd0-12dc2c97af36\", \"ICON_URL\":\"https://img-amc.tason.com/resources/renewal/images/tas-favicon.ico\", \"TITLE\":\"push test\", \"MESSAGE\":\"push msg test\", \"LANDING_URL\": \"https://www.tason.com\", \"REQUEST_UID\":\"1234567890\"}"; 
		ObjectMapper mapper = new ObjectMapper();
		
		WebPushPayload payload;
		try {
			payload = mapper.readValue(json, WebPushPayload.class);
			payload.setPushKey("l");
			payload.setPushValue("https://jsonlint.com/");
			payload.setReportQueue("dev-web-push-report");
			System.out.println("payload :"+payload.getUuid());
			s.sendSync(payload,false);
			
		} catch (Exception e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		} finally {
			if (s != null) s.close();
		}
		
	}
}
